@@ -63,7 +63,7 @@ def label_input_text(labelName:str, labelWidth:int, inputWidth:int, inputID:str,
 def label_input_number(labelName:str, labelWidth:int, inputWidth:int, inputID:str,
                     miniValue:Optional[Union[float, int]]=None, 
                     maxValue:Optional[Union[float, int]]=None,
-                    stepValue:Optional[Union[float, int]]=None,
+                    stepValue:Optional[Union[float, int]]=0.001,
                     defaultInputValue:Optional[Union[float, int]]=None):
     return dbc.Row(children=[
             dbc.Label(labelName, width=labelWidth),
